==> orchestra-0.0.4.tgz: package/test/test.js <==
var orchestra = require('orchestra'), fs = require('fs');


module.exports = {
 
	'emitter' : function(assert) {
		
		var orchestraing = orchestra(function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
		},["geocode1","geocode2"]);

		fs.readFile('/etc/passwd' , orchestraing.emitter("geocode1"));
		fs.stat('/etc/passwd' , orchestraing.emitter("geocode2"));
	},

	'iterate' : function(assert) {
	
		var orchestraing = orchestra(function(data) {
			assert.isNotNull(data);
		}, 3);

		
		orchestraing.on('before-iteration', function(data) {
		//	console.log('antes de uma iteracao');
		});


		orchestraing.on('after-iteration', function(data) {
		//	console.log('depois de uma iteracao');
		});
		
		orchestraing.on('before-iteration-1', function(data) {
		//	console.log('antes da 1 iteracao');
		});
		
		orchestraing.on('after-iteration-1', function(data) {
		//	console.log('depois da 1 iteracao');
		});


		orchestraing.on('before-iteration-3', function(data) {
		//	console.log('antes da 3 iteracao');
		});
		

		var x = ["xxx","yyy","ttt"];
		
		x.map(orchestraing.emitEach());
		
		
	},

	'run 2 cases' : function(assert) {
		var orchestraing = orchestra(function(data) {
			assert.isNotNull(data.signal1);
			assert.isNotNull(data.signal2);
		},["signal1","signal2"]);


		fs.readFile('/etc/passwd', function (err, data) {
			orchestraing.emit("signal1",data);
		});

		fs.readFile('/etc/passwd', function (err, data) {
			orchestraing.emit("signal2",data);
		});
	},

	'run n cases' : function(assert) {
		var orchestraing = orchestra(function(data) {
			// require('sys').log(data);
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			assert.isNotNull(data.ioLoad1);
			assert.isNotNull(data.ioLoad2);

		},["geocode1","geocode2","ioLoad","ioLoad2"]);

		//simulate geocoder stream
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("geocode1",{"lat": -23, "lon" : -45});
		});

		//simulate geocoder stream
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("geocode2",{"lat": -23, "lon" : -45});
		});

		//io
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("ioLoad",data);
		});

		//io
		fs.readFile('/etc/locate.rc', function (err, data) {
			orchestraing.emit("ioLoad2",data);
		});
	},


	'run with 2 orchestra in parallel' : function(assert) {

			var orchestraing = orchestra(function(data) {
				assert.isNotNull(data.signal1);
				assert.isNotNull(data.signal2);
			},["signal1","signal2"]);


			var otherOrchestraing = orchestra(function(data) {
				// require('sys').log(data);
				assert.isNotNull(data.geocode1);
				assert.isNotNull(data.geocode2);
				assert.isNotNull(data.ioLoad1);
				assert.isNotNull(data.ioLoad2);

			},["geocode1","geocode2","ioLoad","ioLoad2"]);

			//simulate geocoder stream
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("geocode1",{"lat": -23, "lon" : -45});
			});

			//simulate geocoder stream
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("geocode2",{"lat": -23, "lon" : -45});
			});


			fs.readFile('/etc/passwd', function (err, data) {
				orchestraing.emit("signal1",data);
			});

			fs.readFile('/etc/passwd', function (err, data) {
				orchestraing.emit("signal2",data);
			});


			//io
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("ioLoad",data);
			});

			//io
			fs.readFile('/etc/locate.rc', function (err, data) {
				otherOrchestraing.emit("ioLoad2",data);
			});


	}


};

==> orchestra-0.0.5.tgz: package/test/test.js <==
var orchestra = require('orchestra'), fs = require('fs');


module.exports = {
 
	'emitter' : function(assert) {
		
		var x = 0;
		
		var orchestraing = new orchestra();
		
		orchestraing.on('geocode1', function(data) {
			assert.isNotNull(data.geocode1);
			x++;
		});

		orchestraing.on('geocode2', function(data) {
			assert.isNotNull(data.geocode2);
			x++;
		});

		orchestraing.on('geocode1 geocode2', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			x++;
		});

		setTimeout(function() {
			assert.equal(x, 3);
		}, 2000);

		fs.readFile('/etc/passwd' , orchestraing.emitter("geocode1"));
		fs.stat('/etc/passwd' , orchestraing.emitter("geocode2"));
	},

	'run 2 cases' : function(assert) {

		var x = 0;

		var orchestraing = new orchestra();
		
		orchestraing.on('geocode1', function(data) {
			assert.isNotNull(data.geocode1);
			x++;
		});

		orchestraing.on('geocode2', function(data) {
			assert.isNotNull(data.geocode2);
			x++;
		});

		orchestraing.on('geocode1 geocode2', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			x++;
		});

		fs.readFile('/etc/passwd', function (err, data) {
			orchestraing.emit("geocode1",data);
		});

		fs.readFile('/etc/passwd', function (err, data) {
			orchestraing.emit("geocode2",data);
		});
		
		setTimeout(function() {
			assert.equal(x, 3);
		}, 2000);
		
	},

	'run n cases' : function(assert) {
		
		
		var orchestraing = new orchestra();
		
		var x = 0;
		
		orchestraing.on('geocode1 geocode2 ioLoad ioLoad2', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			assert.isNotNull(data.ioLoad1);
			assert.isNotNull(data.ioLoad2);
			x++;
		});


		orchestraing.on('geocode1 geocode2 ioLoad', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			assert.isNotNull(data.ioLoad1);
			assert.isNotNull(data.ioLoad2);
			x++;
		});


		orchestraing.on('geocode1 geocode2', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			assert.isNotNull(data.ioLoad1);
			assert.isNotNull(data.ioLoad2);
			x++;
		});


		orchestraing.on('geocode1 geocode2 ioLoad ioLoad2', function(data) {
			assert.isNotNull(data.geocode1);
			assert.isNotNull(data.geocode2);
			assert.isNotNull(data.ioLoad1);
			assert.isNotNull(data.ioLoad2);
			x++;
		});
		
		
		//simulate geocoder stream
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("geocode1",{"lat": -23, "lon" : -45});
		});

		//simulate geocoder stream
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("geocode2",{"lat": -23, "lon" : -45});
		});

		//io
		fs.readFile('/etc/localtime', function (err, data) {
			orchestraing.emit("ioLoad",data);
		});

		//io
		fs.readFile('/etc/locate.rc', function (err, data) {
			orchestraing.emit("ioLoad2",data);
		});
		
		setTimeout(function() {
			assert.equal(x, 4);
		}, 2000);
		
		
	},


	'run with 2 orchestra in parallel' : function(assert) {


			var x = 0;
			
			var orchestraing = new orchestra();
			var otherOrchestraing = new orchestra();
		
			orchestraing.on('signal1 signal2', function(data) {
				assert.isNotNull(data.signal1);
				assert.isNotNull(data.signal2);
				x++;
			});


			orchestraing.on('signal1', function(data) {
				assert.isNotNull(data.signal1);
				assert.isNotNull(data.signal2);
				x++;
			});



			otherOrchestraing.on('geocode1 geocode2 ioLoad ioLoad2', function(data) {
				assert.isNotNull(data.geocode1);
				assert.isNotNull(data.geocode2);
				assert.isNotNull(data.ioLoad1);
				assert.isNotNull(data.ioLoad2);
				x++;
			});


			otherOrchestraing.on('geocode1 geocode2 ioLoad ioLoad2', function(data) {
				assert.isNotNull(data.geocode1);
				assert.isNotNull(data.geocode2);
				assert.isNotNull(data.ioLoad1);
				assert.isNotNull(data.ioLoad2);
				x++;
			});


			otherOrchestraing.on('geocode1 geocode2 ioLoad', function(data) {
				assert.isNotNull(data.geocode1);
				assert.isNotNull(data.geocode2);
				assert.isNotNull(data.ioLoad1);
				assert.isNotNull(data.ioLoad2);
				x++;
			});


			//simulate geocoder stream
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("geocode1",{"lat": -23, "lon" : -45});
			});

			//simulate geocoder stream
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("geocode2",{"lat": -23, "lon" : -45});
			});


			fs.readFile('/etc/passwd', function (err, data) {
				orchestraing.emit("signal1",data);
			});

			fs.readFile('/etc/passwd', function (err, data) {
				orchestraing.emit("signal2",data);
			});


			//io
			fs.readFile('/etc/localtime', function (err, data) {
				otherOrchestraing.emit("ioLoad",data);
			});

			//io
			fs.readFile('/etc/locate.rc', function (err, data) {
				otherOrchestraing.emit("ioLoad2",data);
			});


			setTimeout(function() {
				assert.equal(x, 5);
			}, 2000);


	}


};
